package com.ekexiu.project.bridge.system.service;

import com.ekexiu.project.bridge.system.dao.UserDao;
import com.ekexiu.project.bridge.system.po.User;
import com.ekexiu.project.bridge.system.vo.SessionUser;
import org.jfw.apt.annotation.Autowrie;
import org.jfw.apt.annotation.Nullable;
import org.jfw.apt.web.annotation.LoginUser;
import org.jfw.apt.web.annotation.Path;
import org.jfw.apt.web.annotation.method.InvalidSession;
import org.jfw.apt.web.annotation.method.SetSession;
import org.jfw.apt.web.annotation.operate.Get;
import org.jfw.apt.web.annotation.operate.Post;
import org.jfw.apt.web.annotation.param.JdbcConn;
import org.jfw.apt.web.annotation.param.PathVar;
import org.jfw.util.PageQueryResult;
import org.jfw.util.StringUtil;
import org.jfw.util.exception.JfwBaseException;

import java.sql.Connection;
import java.sql.SQLException;

/**
 * Created by TT on 2018/8/7.
 */
@Path("/sys")
public class SysService {

    public static final String DEFAULT_PW_STR = StringUtil.md5("123456");

    @Autowrie
    private UserDao userDao;


    public UserDao getUserDao() {
        return userDao;
    }

    public void setUserDao(UserDao userDao) {
        this.userDao = userDao;
    }

    @SetSession("JFW_SESSION_LOGIN_USER=result")
    @Path("/login")
    @Post
    public SessionUser login(@JdbcConn Connection con, String account, String pw) throws SQLException {
        User user = userDao.login(con, account, StringUtil.md5(pw));
        if (user != null) {
            SessionUser sessionUser = new SessionUser();
            sessionUser.setAccount(user.getAccount());
            sessionUser.setComp(user.getComp());
            sessionUser.setEmail(user.getEmail());
            sessionUser.setId(user.getId());
            sessionUser.setJob(user.getJob());
            sessionUser.setName(user.getName());
            sessionUser.setPhone(user.getPhone());
            sessionUser.setRemark(user.getRemark());
            sessionUser.setType(user.getType());
            return sessionUser;
        }
        return null;
    }

    @Get
    @Path
    public SessionUser get(@LoginUser SessionUser user) {
        return user;
    }

    @Get
    @Path("/logout")
    @InvalidSession
    public void logout() {
    }

    @Post
    @Path
    public void insert(@JdbcConn(true) Connection con, @LoginUser SessionUser sessionUser, User user) throws SQLException {
        user.setId(StringUtil.buildUUID());
        user.setActive(true);
        user.setPasswd(DEFAULT_PW_STR);
        user.setType(0);
        user.setCreator(sessionUser.getId());
        user.setModifier(sessionUser.getId());
        this.userDao.insert(con, user);
    }

    @Get
    @Path("/id/{id}")
    public User query(@JdbcConn Connection con,@PathVar String id)throws SQLException {
        return this.userDao.query(con, id);
    }

    @Post
    @Path("/update")
    public void update(@JdbcConn(true) Connection con, @LoginUser SessionUser sessionUser, User user) throws SQLException {
        user.setModifier(sessionUser.getId());
        this.userDao.update(con, user);
    }

    @Get
    @Path("/ban")
    public void ban(@JdbcConn(true) Connection con, @LoginUser SessionUser sessionUser, String id) throws SQLException {
        this.userDao.ban(con, sessionUser.getId(), id);
    }

    @Get
    @Path("/pq")
    public PageQueryResult pageQuery(@JdbcConn Connection con, @Nullable String account, @Nullable String name, @Nullable String comp, int pageSize, int pageNo) throws SQLException {
        return this.userDao.pageQuery(con, account == null ? null : "%" + account + "%", name == null ? null : "%" + name + "%", comp == null ? null : "%" + comp + "%", pageSize, pageNo);
    }

    @Get
    @Path("/resetPw")
    public void resetPw(@JdbcConn(true) Connection con,String id)throws SQLException {
        this.userDao.changePw(con, DEFAULT_PW_STR, id);
    }

    @Post
    @Path("/changePw")
    public void changePw(@JdbcConn(true) Connection con,String id,String oldPw,String newPw) throws SQLException, JfwBaseException {
        User user = this.userDao.query(con, id);
        if (user!=null&&StringUtil.md5(oldPw).equals(StringUtil.md5(user.getPasswd()))) {
            this.userDao.changePw(con, StringUtil.md5(newPw), id);
        }else{
            throw new JfwBaseException(100001, "用户不存在或密码不匹配");
        }
    }


}
